@@ -35,30 +35,55 @@ tam.jml.xsi2 <-
 	old_increment <- rep(5,PP1)
     cat(" Item parameter estimation |")
     while (!convergeAllP & ( iterP <= Msteps ) ) {
-      
+   
+# a0 <- Sys.time()
 		  res.p <- calc_prob.v5( iIndex = 1:nitems , A , AXsi , 
 								 B , xsi , theta[ rp3.sel$caseid ,,drop=FALSE ] , 
 								 nrow(rp3.sel) , maxK , TRUE )      		
-		  rprobs <- res.p[["rprobs"]]               
+		  rprobs <- res.p[["rprobs"]]       
+
+# cat("one iteration xsi -- calc prob") ; a1 <- Sys.time(); print(a1-a0) ; a0 <- a1 		  
 		  #compute probability weights, summed over students, so that there is no cycling through students for parameter estimation (p loop)
+		  M1 <- resp.ind[ rp3.sel$caseid , ] * rp3.pweightsM 
+		  t_rprobs <- base::aperm( rprobs , dim=c(3,2,1) )
 		  for (k1 in 1:maxK) {
-			r[,k1] <- colSums(t(rprobs[,k1,]) * resp.ind[ rp3.sel$caseid , ] * rp3.pweightsM, na.rm=TRUE)
+		    M1_k1 <- t_rprobs[,k1,] * M1 
+			r[,k1] <- base::colSums( M1_k1 , na.rm=TRUE)
+
 			for (k2 in 1:maxK) {
-			  rr[,k1,k2] <- colSums(t(rprobs[,k1,]*rprobs[,k2,]) * resp.ind[ rp3.sel$caseid , ] * rp3.pweightsM, na.rm=TRUE)
+			  rr[,k1,k2] <- base::colSums( M1_k1 * t_rprobs[,k2,] , na.rm=TRUE)
 			}
-		  }
+		  }		  
+		  
+
+# cat("one iteration xsi -- matrix 1 (V2)") ; a1 <- Sys.time(); print(a1-a0) ; a0 <- a1 		  
 		  
 		  A_Sq <- AA_bari <- A_bari <- matrix( 0 , PP1 , nitems )
-		  
+		  t_r <- base::t( r )
+          t_rr <- base::aperm( rr , dim=c(3,2,1) ) 		  
+		  t_A.0 <- base::aperm( A.0 , dim=c(3,2,1) )
 		  for (kk in 1:maxK){ 
-			A_bari <- A_bari + t( A.0[ , kk , ] * r[ , kk ] )
-			AA_bari <- AA_bari + t( A.0[ , kk , ]^2 * r[ , kk ] )		
+			A0_r_kk <- A.0[ , kk , ] * r[ , kk ]
+			A_bari <- A_bari + t( A0_r_kk )
+			# A_bari <- A_bari + t_A.0[ , kk , ] * t_r[ kk ,  ]
+			# AA_bari <- AA_bari + t( A.0[ , kk , ]^2 * r[ , kk ] )		
+			AA_bari <- AA_bari + t( A.0[ , kk , ] * A0_r_kk )		
 		  }
 		  for (kk1 in 1:maxK){ 
+			# A0_rr_kk1 <- A.0[,kk1,] * rr[, 
 			for (kk2 in 1:maxK){ 
-			  A_Sq <- A_Sq + t( A.0[,kk1,] * A.0[,kk2,] * rr[ , kk1 , kk2 ] )	
+			  fac <- 1
+			  # A_Sq <- A_Sq + fac * t( A.0[,kk1,] * A.0[,kk2,] * rr[ , kk1 , kk2 ] )	
+			  
+			  if ( kk1 < kk2 ){ fac <- 2 }
+			  if (kk1 <= kk2 ){
+				# A_Sq <- A_Sq + fac * t( A.0[,kk1,] * A.0[,kk2,] * rr[ , kk1 , kk2 ] )	
+				A_Sq <- A_Sq + fac * t( A.0[,kk1,] * A.0[,kk2,] * rr[ , kk1 , kk2 ] )	
+				}
 			}
 		  }
+# cat("one iteration xsi -- matrix 2 (V2)") ; a1 <- Sys.time(); print(a1-a0) ; a0 <- a1
+ 		  
 			  # A							[ nitems , maxK , length(xsi) ]	
 			  # A_Sq, AA_bari, A_bari		[ length(xsi) , nitems ]
 			  # r							[ nitems , maxK ]
@@ -76,6 +101,8 @@ tam.jml.xsi2 <-
 		  
 		  expected <- rowSums (A_bari, na.rm=TRUE) # sum over items
 		  err <- rowSums(AA_bari - A_Sq, na.rm=TRUE)   #sum over the items
+
+# cat("one iteration xsi -- matrix 3") ; a1 <- Sys.time(); print(a1-a0) ; a0 <- a1 		  
 		  
 		  err_inv <- abs (1/( abs(err) + 10^(-10) ))		  
 		  scores <- ItemScore * ( ! convergeP ) - expected
@@ -96,9 +123,9 @@ tam.jml.xsi2 <-
 		  p_loop <- est.xsi.index[convergeP[est.xsi.index]==FALSE]
 		  convergeAllP <- (sum(convergeP[est.xsi.index]) == length(est.xsi.index))  	  
 		  cat("-")  
+# cat("one iteration xsi -- update") ; a1 <- Sys.time(); print(a1-a0) ; a0 <- a1 		  
     } # end of all parameters convergence
 
-    
     res <- list( "xsi" = xsi , "errorP" = errorP, 
                  "maxChangeP" = max(abs( xsi - old_xsi ) ) )
     return (res)  
