@@ -2,45 +2,76 @@
 
 ##########################################################################
 # estimation of item intercepts
-.mml.3pl.est.intercepts <- function( max.increment , np , est.xsi.index0 , 
+tam.mml.3pl.est.intercepts <- function( max.increment , np , est.xsi.index0 , 
 		Msteps , nitems , A , AXsi , B , xsi , guess , theta , nnodes , maxK ,
 		progress , itemwt , indexIP.no , indexIP.list2 ,
 		ItemScore , fac.oldxsi , rprobs , xsi.fixed , convM , rprobs0 ,
-		n.ik , N.ik  , xsi.prior ){
+		n.ik , N.ik  , xsi.prior , indexIP.list)
+{
       converge <- FALSE
       Miter <- 1
 	  eps <- 1e-10
 	  oldxsi <- xsi
       old_increment <- rep( max.increment , np )
       est.xsi.index <- est.xsi.index0
+	  
+	  #***************************************************
       while ( !converge & ( Miter <= Msteps ) ) {	
-        #      xbar2 <- xxf <- xbar <- rep(0,np)
-        # Only compute probabilities for items contributing to param p
-        if (Miter > 1){ 
-          res.p <- .mml.3pl.calc_prob.v5( iIndex=1:nitems , A=A , AXsi=AXsi , B=B , 
-                                 xsi=xsi , theta=theta , nnodes=nnodes, maxK=maxK , 
-								 guess=guess )					
-          rprobs <- res.p[["rprobs"]]
-          rprobs0 <- res.p$rprobs0		  
-        }
-
-        res <- .mml.3pl.calc_exp_TK3( rprobs , A , np , est.xsi.index , itemwt ,
-                             indexIP.no , indexIP.list2 , rprobs0 , guess ,
-							 n.ik , N.ik )
-        xbar <- res$xbar
-        xbar2 <- res$xbar2
-        xxf <- res$xxf
-        ItemScore <- res$iscore		
-        
-        # Compute the difference between sufficient statistic and expectation
-        diff <- as.vector(ItemScore) - xbar
-        #Compute the Newton-Raphson derivative for the equation to be solved
-        deriv <- xbar2 - xxf 	
+        #      xbar2 <- xxf <- xbar <- rep(0,np)		
+		# numerical differentiation parameter
+		h <- 1E-4
+		
+		#----- switch with respect to existence of guessing parameter
+		guess_exists <- base::max( guess ) > eps
+		
+		if ( ! guess_exists ){
+			# Only compute probabilities for items contributing to param p
+			if (Miter > 1){ 
+			  res.p <- tam_mml_3pl_calc_prob( iIndex=1:nitems , A=A , AXsi=AXsi , B=B , 
+									 xsi=xsi , theta=theta , nnodes=nnodes, maxK=maxK , 
+									 guess=guess )					
+			  rprobs <- res.p[["rprobs"]]
+			  rprobs0 <- res.p$rprobs0		  
+			}
 
+			res <- .mml.3pl.calc_exp_TK3( rprobs , A , np , est.xsi.index , itemwt ,
+								 indexIP.no , indexIP.list2 , rprobs0 , guess ,
+								 n.ik , N.ik )
+			xbar <- res$xbar
+			xbar2 <- res$xbar2
+			xxf <- res$xxf
+			ItemScore <- res$iscore					
+			# Compute the difference between sufficient statistic and expectation
+			diff <- base::as.vector(ItemScore) - xbar
+			#Compute the Newton-Raphson derivative for the equation to be solved
+			deriv <- xbar2 - xxf 	
+		}
+		
+		if ( guess_exists){
+			NX <- base::length(xsi)		
+			ll0 <- base::rep( NA , NX )
+			ll1m <- ll1p <- NA*ll0
+			for (xx in 1:NX){
+				# xx <- 1		
+				iIndex <- 1:nitems				
+				# iIndex <- indexIP.list[[xx]]				
+				ll0[xx] <- tam_mml_3pl_calc_total_ll( iIndex= iIndex , A=A , B=B , xsi=xsi , theta=theta ,
+								nnodes=nnodes , guess=guess , n.ik=n.ik , eps=eps )	
+				ll1p[xx] <- tam_mml_3pl_calc_total_ll( iIndex= iIndex , A=A , B=B , 
+								xsi= tam_mml_3pl_vec_add_increment( vec=xsi , h=h , index=xx ) , 
+								theta=theta, nnodes=nnodes , guess=guess , n.ik=n.ik , eps=eps )
+				ll1m[xx] <- tam_mml_3pl_calc_total_ll( iIndex= iIndex , A=A , B=B , 
+								xsi= tam_mml_3pl_vec_add_increment( vec=xsi , h=-h , index=xx ) , 
+								theta=theta, nnodes=nnodes , guess=guess , n.ik=n.ik , eps=eps )
+			}
+			res <- tam_mml_3pl_difference_quotient( d0=ll0 , d0p=ll1p , d0m=ll1m , h=h)
+			diff <- res$d1
+			deriv <- res$d2
+		}
+		
 		#***********************
 		# xsi prior
 		  if ( ! is.null(xsi.prior) ){
-			  h <- .0001	
 			  d0  <- log( stats::dnorm( xsi , mean=xsi.prior[,1] , 
 						       sd=xsi.prior[,2] ) + eps)
 			  d0p  <- log( stats::dnorm( xsi + h , mean=xsi.prior[,1] , 
@@ -92,31 +123,5 @@
 		}
 #######################################################################
 
+.mml.3pl.est.intercepts <- tam.mml.3pl.est.intercepts
 
-###########################################################
-# faster version of calc_exp_TP3
-.mml.3pl.calc_exp_TK3 <- function( rprobs , A , np , est.xsi.index , itemwt ,
-	indexIP.no , indexIP.list2 , rprobs0 , guess , n.ik , N.ik){
-	CC <- dim(rprobs)[2]
-	TP <- dim(rprobs)[3]
-	NXSI <- dim(A)[3]
-	NI <- dim(A)[1]
-	# restructure rprobs and AL	
-	AL <- matrix( A , nrow=NI*CC , ncol=NXSI )	
-	AL[ is.na(AL) ] <- 0
-	rprobsL <- matrix( rprobs , nrow=NI*CC , ncol=TP )
-	rprobsL[ is.na(rprobsL) ] <- 0
-	rprobsL0 <- matrix( rprobs0 , nrow=NI*CC , ncol=TP )
-	rprobsL0[ is.na(rprobsL0) ] <- 0
-	# use nik
-	nik <- as.vector(n.ik)
-	ni <- as.vector(N.ik)
-
-	#******
-	# Call .mml.3pl function  (define CALL)	
-	res <- .Call("mml3pl_tam_calcexp" ,  np , rprobsL , AL ,	indexIP.no , 
-			    indexIP.list2 , est.xsi.index , CC , itemwt , rprobsL0 , 
-			    guess , nik , ni , PACKAGE="TAM")
-	return(res)
-		}
-		
\ No newline at end of file
